/* ccgo: igs/static.cc
 * 
 * Copyright 2002 Chun-Chung Chen <cjj@u.washington.edu>
 * 
 * This program is free software; you can redistribute it and'or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include "static.hh"
#include <gtkmm/box.h>
#include <gtkmm/button.h>
#include <gtkmm/stock.h>

using namespace igs;

void Static::on_hide()
{
	delete this;
}

Static::Static(unsigned z) :
	head_line("Static game board")
{
	board.set_board_size(z); // not needed

	Gtk::VBox * vb = Gtk::manage(new Gtk::VBox);
	add(* vb);

	vb->pack_start(head_line, Gtk::PACK_SHRINK);

	Gtk::HBox * hb = Gtk::manage(new Gtk::HBox);
	vb->pack_start(* hb);

	vb->pack_start(date, Gtk::PACK_SHRINK);
	vb->pack_start(record, Gtk::PACK_SHRINK);

	hb->pack_start(board);

	vb = Gtk::manage(new Gtk::VBox);
	hb->pack_end(* vb, Gtk::PACK_SHRINK);

	Gtk::Button * bt = Gtk::manage(new Gtk::Button(Gtk::Stock::CLOSE));
	vb->pack_end(* bt, Gtk::PACK_SHRINK);
	bt->signal_clicked().connect(SigC::slot(* this, & Window::hide));

	set_default_size(400, 350);

	show_all();
}

void Static::set_board(const Board & b)
{
	set_title(b.white + " vs " + b.black);
	head_line.set_text("Static board: " + b.white + " vs " + b.black);
	board.set_board_size(b.board_size);
	if (b.is_score) {
		if (b.score.length()) record.set_text("Score: " + b.score);
	} else {
		if (b.date.length()) date.set_text("Date: " + b.date);
		if (b.record.length()) record.set_text("Record: " + b.record);
	}
	for (int x = 0; x < b.board_size; x ++) {
		for (int y = 0; y < b.board_size; y ++) {
			switch (b.state[go::Loc(x, y).expand(b.board_size)]) {
			case 0:
				board.set_site(go::Loc(x, y), go::STATE_BLACK);
				break;
			case 1:
				board.set_site(go::Loc(x, y), go::STATE_WHITE);
				break;
			default:
				board.set_site(go::Loc(x, y), go::STATE_EMPTY);
			}
		}
	}
}
